@@ -1,5 +1,5 @@
 package Kephra::Config::Default::GlobalSettings;
-our $VERSION = '0.16';
+our $VERSION = '0.05';
 
 use strict;
 use warnings;
@@ -8,16 +8,14 @@ sub get {
 	return {
 		about => {
 			purpose => 'build in global settings',
-			version => $Kephra::VERSION || 'no',
+			version => $Kephra::VERSION,
 		},
 		app => {
-			app_data_sub_dir => 'interface',
-			cache => {
-				file => 'commands.yaml',
-				sub_dir => 'cache',
-				use => 1,
-			},
 			commandlist => {
+				cache => {
+					file => 'interface/cache/commands.conf',
+					'use' => 1,
+				},
 				file => 'interface/commands.conf',
 				node => 'commandlist',
 			},
@@ -28,18 +26,16 @@ sub get {
 					document_list => '&document_change',
 					document_selection => 'textselection_contextmenu',
 					file_history => '&file_history',
-					insert_templates => '&insert_templates',
-					marker_margin => 'markermargin_contextmenu',
-					status_eol => 'status_lineendchar_contextmenu',
-					status_encoding => 'status_encoding_contextmenu',
-					status_info => 'status_info_contexmenu',
-					status_syntaxmode => 'status_syntaxstyle_contextmenu',
-					status_tab => 'status_whitespace_contextmenu',
+					file_insert_templates => '&insert_templates',
+					status_eol => 'document_lineendchar_contextmenu',
+					status_info => 'document_info_contexmenu',
+					status_syntaxmode => 'document_syntaxstyle_contextmenu',
+					status_tab => 'document_whitespace_contextmenu',
 					toolbar_search => 'searchbar_contextmenu',
 				},
 			},
-			error_output => 'panel',                         # (dialog|console|panel|none)
-			iconset_path => 'interface/icon/set/jenne',      # rootpath for all icons
+			error_output => 'dialog',                         # (dialog|console|none)
+			iconset_path => 'interface/icon/set/jenne',                # rootpath for all icons
 			localisation => {
 				directory => 'localisation',
 				file => 'english.conf',                                # file relative to the localisation directory, defines language of the texts in the program
@@ -48,83 +44,72 @@ sub get {
 				file => 'interface/mainmenu.yml',
 				node => 'full_menubar',
 				responsive => 1,                              # (0|1) 0 prevent menubar item shading
-				visible => 1,
 			},
 			panel => {
 				notepad => {
-					content_file => 'global/data/notepad_content.txt',
+					content => 'extension/notepad/content.txt',
 					eval_with => 'eval',
-					font_family => 'Courier New',
 					font_size => 10,
 					size => 180,
-					splitter_pos => 300,
 					visible => 0,
 				},
 				output => {
 					append => 0,
 					back_color => '000022',
-					font_family => 'Arial',
-					font_size => 10,
+					font_size => 9,
 					fore_color => 'ffffff',
-					interpreter_path => 'perl',
 					size => 100,
 					visible => 0,
 				},
 			},
-			searchbar => {
-				autofocus => 0,
-				autohide => 0,
-				contextmenu => 'toolbar_search',
-				contextmenu_visible => 1,
-				file => 'interface/appbars.conf',
-				node => 'searchbar',
-				position => 'below',        # (above|below|bottom)
-				visible => 1,
-			},
 			statusbar => {
-				contextmenu_visible => 1,
-				file => 'interface/appbars.yml',
 				interactive => 1,
-				node => 'statusbar',
 				msg_nr => 0,
 				visible => 1,
 			},
 			tabbar => {
-				close_button => 'current'     ,# (all|current|active|one|right|no) current = active
-											   # one = right, on right border
-				contextmenu => 'document_list',# -NI id of connected context menu
-				contextmenu_visible => 1,      # (0|1) enable conextmenu over tabbar
-				file_info => 'file_name',      # (file_name|firstname) which part of filename to show
+				button => {
+					close => 1,
+					new => 0,
+				},
+				contextmenu => 'document_list',# id of connected context menu
+				contextmenu_use => 1,          # (0|1) enable conextmenu ovr tabbar
+				file_info => 'name',           # -NI (name|firstname) which part of filename to show
 				info_symbol => 1,              # (0|1) show *(unsaved) and #(write protected) symbols on end of tabs
-				insert_new_tab => 'rightmost', # (left|right[most]) tab position of opened file
+				insert => 'rightmost',         # -NI tab position of opened file
 				mark_configs => 1,             # (0|1) set configfile names in square brackets
 				max_tab_width => 25,           # max tab width in chars, longer filenames will be cut and ... added
-				middle_click => 'file-close-current',# -NI command that is performed when middle click over tabbar
-				movable_tabs => 1,             # (0|1) if 0 tabs can't moved by mouse or key 
+				middle_click => 'file-close-current',  # command that is performed when middle click over tabbar
 				number_tabs => 0,              # (0|1) display a number before the file name in the tabs
-				switch_back => 1,              # -NI (0|1) switch back if you klick on current tab
-				tablist_button => 1,           # (0|1)
-				visible => 1,                  # (0|1)
+				seperator_line => 1,           # (0|1) visibility of seperator line above
+				switch_back => 1,              # (0|1) switch back if you klick on current tab
+				visible => 1,                  # (0|1) in tabbar you can see which files are open
 			},
 			toolbar => {
-				contextmenu => 0,
-				file => 'interface/appbars.yml',
-				node => 'main_toolbar',
-				responsive => 1,
-				size => 16,
-				visible => 1,
+				all => {
+					responsive => 1,
+					defaultfile => 'interface/appbars.yml',
+				},
+				main => {
+					contextmenu => 0,
+					file => 'interface/appbars.yml',
+					node => 'main_toolbar',
+					size => 16,
+					visible => 1,
+				},
+				search => {
+					autofocus => 1,
+					autohide => 0,
+					contextmenu => 'toolbar_search',
+					file => 'interface/appbars.conf',
+					node => 'searchbar',
+					position => 'bottom',     # (top|middle|bottom)
+					visible => 1,
+				},
 			},
 			window => {
-				default => {
-					position_x => 0,
-					position_y => 0,
-					size_x => 800,
-					size_y => 600,
-				},
-				fullscreen => 0,
 				icon => 'interface/icon/app/proton.xpm',
 				max_number => 1,
-				maximize_editpanel => 0,
 				position_x => 10,
 				position_y => 10,
 				save_position => 1,
@@ -138,57 +123,39 @@ sub get {
 										# $doccount - nr of all opened files
 										# $appname - name of this programm
 										# $version - version of this programm
-				transparency => 0.2,	# how much transparent if active, 1 = 100% = invisible
-				transparent => 0,		# (0|1) trancparency active ?
 			},
 			xp_style => 1,
 		},
 		dialog => {
 			button_handing => 'right',
+			search => {
+				save_position => 1,
+				position_y    => 100,
+				position_x    => 100,
+				tooltips      => 1,
+			},
 			config => {
 				save_position => 1,
 				position_y    => 100,
 				position_x    => 100,
 				tooltips      => 1,
 			},
-			search => {
-				save_position => 1,
-				position_y    => 100,
-				position_x    => 100,
-				tooltips      => 1,
-				transparency  => 0.2,  # 0 - full visible .. 1 - invisible
-				width         => 436,
-			},
 		},
 		editpanel => {
-			DND_mode => 'copy',
+			DND_mode       => 'copy',
 			auto => {
 				brace => {
 					glue_tangent => 0,
 					indention => 1,# indet after opening braces 1 tab more
-					join => 1,     # deletes closing bracket if there are 2 and 1 has no matching partner
+					join => 1,    # deletes closing bracket if there are 2 and 1 has no matching partner
 					make => 1,     # generates closing bracket for ne blocks
 				},
-				focus => 0,        # set focus on editpanel while onmouseover
 				indention => 1,    # indents new lines like previous
 			},
 			contextmenu => {
-				ID_margin => 'marker_margin',
-				ID_normal => 'document_context',
 				ID_selection => 'document_selection',
+				ID_normal => 'document_context',
 				visible => 'custom',
-				margin => 1,
-			},
-			control => {
-				mouse_function => {
-					'left-selection' => 'edit-copy',
-					'left-middle' => 'edit-paste',
-					'left-right' => 'edit-cut',
-					'middle-selected' => 'edit-insert-selection-at-cursor',
-					'middle-selection' => 'find-selection, find-next',
-					'middle' => 'goto-last-edit',
-				},
-				use_mouse_function => 1,
 			},
 			font => {
 				family => 'Courier New',
@@ -213,7 +180,7 @@ sub get {
 					width  => 2
 				},
 				caret_line => {
-					color   => 'f5f5a5',
+					color   => 'f2f2df',
 					visible => 1,
 				},
 				end_of_line_marker => 0,
@@ -224,7 +191,7 @@ sub get {
 				right_margin => {
 					color    => 'ccccff',
 					position => 80,
-					style    => 1,
+					style    => 1
 				},
 				selection => {
 					back_color => '001177',
@@ -237,19 +204,13 @@ sub get {
 			},
 			line_wrap => 0,
 			margin => {
-				fold => {
-					back_color => 'fff5f5',
-					fore_color => 'aa9977',
-					flag_line => 1,
-					keep_caret_visible => 1,
-					style => 'boxes',          # (boxes|arrows) apearance of the fold marker
-					visible => 1,
-				},
+				fold => 0,
 				linenumber => {
 					autosize   => 1,
-					back_color => 'd8d8d4',
-					fore_color => '777788',
-					min_width  => 3,
+					back_color => 'dddddd',
+					fore_color => '111144',
+					min_width  => 4,
+					width      => 4,
 					visible    => 1,
 				},
 				marker => {
@@ -257,35 +218,25 @@ sub get {
 					fore_color => '000055',
 					visible    => 1
 				},
-				text => 2
+				text => 4
 			},
 			scroll_width => '640',
 			word_chars => '$%-@_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789',
 		},
 		file => {
 			current => {
-				directory => '',
+				directory => '/kephra/config/global/',
+				'open'    => [],
 			},
 			defaultsettings => {
-				new => {                  # defaults for new docs
-					EOL      => 'OS',     # (OS|auto|cr|lf|cr+lf) end of line character, OS means current OS standart -NI auto means take setting of the last touched file
-					codepage => 'ascii',  # (8bit|utf8) codepage, used for charset
-					cursor_pos => 0,
-					readonly => 'no',     # (0|1|2|on|off|protect) if =1 it set a write protection on readonly files
-					syntaxmode => 'perl', # (auto|none|lang_id) which syntaxstyle on new files
-					tab_size => '4',      # (0..n) how much (white)spaces equals one tab?
-					tab_use  => '1',      # (0|1) use of tab chars
-				},
-				open => {                 # defaults for opened files
-					EOL         => 'auto',# (auto|cr+lf|cr|lf) EOL of opened files, if not set to auto, 
-				                          # the file automaticly will converted to set value
-					codepage    => 'auto',# (ascii|utf8) codepage, used for charset
-					cursor_pos  => 0,
-					readonly    => 'protect', # (0|1|2|on|off|protect) if =1 it set a write protection on readonly files
-					syntaxmode  => 'auto',    # (auto|none|lang_id) which syntaxstyle on new files
-					tab_size    => '4',       # (0..n) how much (white)spaces equals one tab?
-					tab_use     => 'auto',    # (auto|0|1) use of tab chars
-				},
+				EOL_open    => 'auto',    # (auto|cr+lf|cr|lf) EOL settings for new files, -NI auto means take setting of the last touched file
+				EOL_new     => 'cr+lf',   # (auto|cr|lf|cr+lf) EOL of opened files, if not set to auto, the file automaticly will converted
+				codepage    => 0,         # -NI codepage of the used charset, not implemented yet
+				cursor_pos  => 0,
+				readonly    => 'protect', # (0|1|2|on|off|protect) if =1 it set a write protection on readonly files
+				syntaxmode  => 'auto',    # (auto|none|lang_id) which syntaxstyle on new files
+				tab_size    => '4',       # (0..n) how much (white)spaces equals one tab?
+				tab_use     => 0,         # use tab chars
 			},
 			endings => {
 				ada     => 'ada ads adb',
@@ -339,14 +290,18 @@ sub get {
 				text   => 'text',
 				web    => 'css html php perl js',
 			},
-			open => {
+			history => {
+				'length' => 10,
+				path => [],
+			},
+			'open' => {
 				dir_recursive       => 1, # opens dirs recursive
 				each_once           => 1, # opens each file only once
 				in_current_dir      => 1, # opens dialog with the directory of current file
 				into_empty_doc      => 0, # replacing new empty documents while opening a file
 				into_only_empty_doc => 1, # replacing new empty doc if the empty is the only one
 				notify_change       => 30,# (0..n) timer executed check if file has changed in sec
-				only_text           => 0, # to open only text files
+				only_text           => 1, # to open only text files
 				single_doc          => 0, # opens only 1 document at once, enables an single document editor
 			},
 			save => {
@@ -362,22 +317,14 @@ sub get {
 				unchanged     => 0,     # saves (touches) automaticly also unchanged files
 			},
 			session => {
-				auto => {
-					file => 'current.yaml',
-					node => '',
-					save => 1,
-				},
+				autosave  => 'extern',
 				backup    => 'backup.yaml',
+				current   => 'current.yaml',
 				directory => 'session', # subdir of config where to look for session files
-				history   => {
-					file => 'history.yml',
-					length => 13,
-					node => '',
-					save => 1,
-				},
+				node      => 'files',
 			},
 			templates => {
-				directory => 'template',
+				directory => 'templates',
 				file      => 'perl.conf',
 			},
 		},
@@ -392,17 +339,12 @@ sub get {
 				match_whole_word => 0,
 				match_word_begin => 0,
 			},
-			data_file => 'global/data/search.yml',
 			history => {
-				length => 12,
+				'length' => 12,
 				remember_only_matched => 1,
 				save => 1,
-				use => 1,
-			},
-			marker => {
-				any => 1,
-				wrap => 1,
-			},
+				'use' => 1,
+			}
 		},
 		texts => {
 			special    => 'english/special_feature.txt',
@@ -417,4 +359,4 @@ sub get {
 	}
 }
 
-1;
\ No newline at end of file
+1;
