@@ -1,5 +1,5 @@
 package Kephra::Document::Internal;
-our $VERSION = '0.13';
+our $VERSION = '0.12';
 
 use strict;
 use warnings;
@@ -25,8 +25,6 @@ sub current_nr {
 		$Kephra::temp{current_doc}    = temp_data()->[$nr];
 	} else { $Kephra::document{current_nr} }
 }
-sub get_previous_nr { previous_nr() }
-sub set_previous_nr { previous_nr(@_) if @_ }
 sub get_current_nr { current_nr() }
 sub set_current_nr { current_nr(@_) if @_ }
 sub all_nr         { [ 0 .. last_nr() ]   }
@@ -184,7 +182,8 @@ sub add {
 	if ( defined $file_name and -e $file_name ) {
 
 		# open only text files and empty files
-		return if -B $file_name and $Kephra::config{file}{open}{only_text} == 1;
+		return if ( !-z $file_name and -B $file_name
+			and $Kephra::config{file}{open}{only_text} == 1 );
 
 		# check if file is already open and goto this already opened
 		if ( $Kephra::config{file}{open}{each_once} == 1){
@@ -310,7 +309,6 @@ sub eval_properties {
 	Kephra::Document::set_tab_mode( $doc_attr->{tab_use} );
 	Kephra::Document::set_tab_size( $doc_attr->{tab_size} );
 	Kephra::Document::set_readonly( $doc_attr->{readonly} );
-	Kephra::Document::set_codepage( $doc_attr->{codepage} );
 
 	# setting selection and caret position
 	if ($doc_data->{selstart} and $doc_data->{selstart}) {
