@@ -1,5 +1,5 @@
 package Kephra::Edit::Search;
-our $VERSION = '0.31';
+our $VERSION = '0.29';
 
 use strict;
 use warnings;
@@ -7,150 +7,102 @@ use warnings;
 # internal and menu functions about find and replace text
 # drag n drop target class
 
+use Wx qw(
+	wxSTC_FIND_WHOLEWORD wxSTC_FIND_MATCHCASE wxSTC_FIND_WORDSTART
+	wxSTC_INDIC_STRIKE wxSTC_INDIC_DIAGONAL wxSTC_INDIC_TT wxSTC_INDIC_PLAIN
+	wxSTC_FIND_REGEXP wxYES wxCANCEL
+);
+
 # internal functions
-my ($find_item, $found_pos, $old_pos, $replace_item);
-my $flags;
-my $history_refresh;
-my @find_history;
-my @replace_history;
-sub _config    { Kephra::API::settings()->{search} }
-sub _attributes{ _config()->{attribute} }
-sub _history   { _config()->{history}   }
-sub _find_pos  { $found_pos }
+sub _attributes{ $Kephra::config{search}{attribute} }
+sub _history   { $Kephra::config{search}{history} }
 
 sub _refresh_search_flags {
 	my $attr = _attributes();
-	$flags = 0;
+	my $flags = 0;
 
-	$flags |= &Wx::wxSTC_FIND_MATCHCASE
+	$flags |= wxSTC_FIND_MATCHCASE
 		if defined $attr->{match_case} and $attr->{match_case};
 	if ( defined $attr->{match_whole_word} and $attr->{match_whole_word} ) {
-		$flags |= &Wx::wxSTC_FIND_WHOLEWORD
+		$flags |= wxSTC_FIND_WHOLEWORD
 	} else {
-		$flags |= &Wx::wxSTC_FIND_WORDSTART
+		$flags |= wxSTC_FIND_WORDSTART
 			if $attr->{match_word_begin} and $attr->{match_word_begin};
 	}
-	$flags |= &Wx::wxSTC_FIND_REGEXP
+	$flags |= wxSTC_FIND_REGEXP
 		if defined $attr->{match_regex} and $attr->{match_regex};
+	$Kephra::temp{search}{flags} = $flags;
 }
 
-
-sub load_search_data {
-	my $file = Kephra::Config::filepath( _config()->{data_file} );
-	my $config_tree = Kephra::Config::File::load($file);
-
-	set_find_item( $config_tree->{find}{item}  || '' );
-	set_replace_item( $config_tree->{replace}{item}  || '' );
-	if (defined $config_tree->{find}{history}){
-		if (ref $config_tree->{find}{history} eq 'ARRAY'){
-				 @find_history = @{ $config_tree->{find}{history} };
-		} else { $find_history[0] = $config_tree->{find}{history} }
-	}
-	if (defined $config_tree->{replace}{history}){
-		if (ref $config_tree->{replace}{history} eq 'ARRAY'){
-				 @replace_history = @{ $config_tree->{replace}{history} };
-		} else { $replace_history[0] = $config_tree->{replace}{history} }
-	}
+sub _init_history {
 	my $history = _history();
 
 	# remove dups and cut to the configured length
 	if ( $history->{use} ) {
 		my ( %seen1, %seen2 );
-		my @uniq = grep { !$seen1{$_}++ } @find_history;
-		@find_history = splice @uniq, 0, $history->{length};
-		@uniq = grep { !$seen2{$_}++ } @replace_history;
-		@replace_history = splice @uniq, 0, $history->{length};
+		my @items = @{ Kephra::Config::Tree::_convert_node_2_AoS
+			( \$history->{find_item} ) };
+		my @uniq = grep { !$seen1{$_}++ } @items;
+		@{ $history->{find_item} } = splice @uniq, 0, $history->{length};
+		@items = @{ Kephra::Config::Tree::_convert_node_2_AoS
+				( \$history->{replace_item} ) };
+		@uniq = grep { !$seen2{$_}++ } @items;
+		@{ $history->{replace_item} } = splice @uniq, 0, $history->{length};
 	} else {
-		@find_history    = ();
-		@replace_history = ();
+		@{ $history->{find_item} }    = ();
+		@{ $history->{replace_item} } = ();
 	}
 	# search item is findable
-	$found_pos = 0;
-	Kephra::EventTable::trigger
-		('find.item.history.changed', 'replace.item.history.changed');
-	Kephra::Edit::Marker::restore_bookmarks( $config_tree->{bookmark} );
+	$Kephra::temp{search}{item}{found} = 1;
 }
 
-sub save_search_data {
-	my $file = Kephra::Config::filepath( _config()->{data_file} );
-	my $config_tree = Kephra::Config::File::load($file);
-	$config_tree->{find}{item}       = get_find_item();
-	$config_tree->{find}{history}    = get_find_history();
-	$config_tree->{replace}{item}    = get_replace_item();
-	$config_tree->{replace}{history} = get_replace_history();
-	$config_tree->{bookmark}         = Kephra::Edit::Marker::get_bookmark_data();
-	Kephra::Config::File::store($file, $config_tree);
-	Kephra::Edit::Marker::store();
-}
-#
-sub get_find_item { $find_item  || ''}
-sub set_find_item {
-	my $old = $find_item;
-	my $new = shift;
-	if (defined $new and (not defined $old or $new ne $old)){
-		$find_item = $new;
-		$found_pos = -1;
-		Kephra::EventTable::trigger('find.item.changed');
-	}
-}
-
-sub set_selection_as_find_item {
-	set_find_item( Kephra::App::EditPanel::_ref()->GetSelectedText )
-}
-
-sub item_findable       { _exist_find_item() }
-sub _exist_find_item    { (defined $find_item and $find_item) ? 1 : 0 }
-sub _exist_replace_item { (defined $replace_item and $replace_item) ? 1 : 0 }
-
-sub get_replace_item { $replace_item || ''}
-sub set_replace_item {
-	my $old = $replace_item;
-	my $new = shift;
-	if (defined $new and (not defined $old or $new ne $old)){
-		$replace_item = $new;
-		Kephra::EventTable::trigger('replace.item.changed');
-	}
-}
-
-sub set_selection_as_replace_item {
-	set_replace_item( Kephra::App::EditPanel::_ref()->GetSelectedText )
-}
-sub get_find_history    { \@find_history    }
-sub get_replace_history { \@replace_history }
 sub refresh_find_history {
-	my $found_match = shift;
-	my $find_item   = get_find_item();
-	my $history     = _history();
-	return unless $history->{use};
-	# check if refresh needed
-	return if $history->{remember_only_matched} and not $found_match;
+	my $found_match       = shift;
+	my $current_find_item = get_find_item();
+	my $history           = _history();
+	my $refresh_needed;
 
-	if ($find_item and $find_history[0] ne $find_item) {
-		for ( 0 .. $#find_history ) {      # delete the dup
-			if ( $find_history[$_] eq $find_item ) {
-				@find_history = @find_history[ 0 .. $_-1, $_+1 .. $#find_history ];
+	# check if refresh needed
+	if ( $history->{remember_only_matched} ) {
+		$refresh_needed = 1 if defined $found_match and $found_match > 0;
+	} else { $refresh_needed = 1 }
+
+	# delete dups
+	if ($refresh_needed and _exist_find_item() 
+		and ($history->{find_item})[0] ne $current_find_item) {
+		my $item   = $history->{find_item};
+		my $length = $history->{length} - 1;
+		for ( 0 .. $#{$item} ) {
+			if ( $$item[$_] eq $current_find_item ) {
+				@{$item} = @{$item}[ 0 .. $_ - 1, $_ + 1 .. $#{$item} ];
 				last;
 			}
-			pop @find_history if $_ == $history->{length} - 1;
+			pop @{$item} if ( $_ == $length );
 		}
-		unshift @find_history, $find_item; # insert new history item
-		Kephra::EventTable::trigger('find.item.history.changed');
+
+		# new history item
+		unshift @{$item}, $current_find_item;
+		$Kephra::temp{search}{history}{refresh} = 1;
+	} else {
+		$Kephra::temp{search}{history}{refresh} = 0;
 	}
 }
+
 sub refresh_replace_history {
-	my $replace_item = get_replace_item();
+	my $current_item = get_replace_item();
 	my $history      = _history();
 
-	if ($replace_item) {
-		for ( 0 .. $#replace_history ) {
-			if ( $replace_history[$_] eq $replace_item ) {
-				@replace_history = @replace_history[ 0 .. $_-1, $_+1 .. $#replace_history ];
+	if ($current_item) {
+		my $item   = $history->{replace_item};
+		my $length = $history->{length} - 1;
+		for ( 0 .. $#{$item} ) {
+			if ( $$item[$_] eq $current_item ) {
+				@{$item} = @{$item}[ 0 .. $_ - 1, $_ + 1 .. $#{$item} ];
 				last;
 			}
-			pop @replace_history if $_ == $history->{length} - 1;
+			pop @{$item} if ( $_ == $length );
 		}
-		unshift @replace_history, $replace_item;
-		Kephra::EventTable::trigger('replace.item.history.changed');
+		unshift @{$item}, $current_item;
 	}
 }
 
@@ -165,6 +117,14 @@ sub _caret_2_sel_end {
 	}
 }
 
+sub item_findable       { _exist_find_item();
+#print "findable:".$Kephra::temp{search}{item}{found}."\n";
+#return $Kephra::temp{search}{item}{found} > 0;
+}
+sub _exist_find_item    { length( get_find_item() ) }
+sub _exist_replace_item { length( get_replace_item() ) }
+#
+#
 #
 sub set_range{ _attributes()->{in} = shift }
 sub get_range{ _attributes()->{in}         }
@@ -197,6 +157,43 @@ sub switch_attribute{
 }
 
 # find helper function
+sub get_find_item {
+	my $h = _history();
+	$h->{current_find_item} if defined $h->{current_find_item};
+}
+
+sub set_find_item {
+	my $old = get_find_item();
+	my $new = shift;
+	if (defined $new and $new ne $old){
+		_history()->{current_find_item} = $new;
+		$Kephra::temp{search}{item}{found} = 1;
+		Kephra::API::EventTable::trigger('find.item.changed');
+	}
+}
+
+sub set_selection_as_find_item {
+	set_find_item( Kephra::App::EditPanel::_ref()->GetSelectedText )
+}
+
+sub get_replace_item {
+	$Kephra::config{search}{history}{current_replace_item}
+		if defined $Kephra::config{search}{history}{current_replace_item}
+}
+
+sub set_replace_item {
+	my $old = $Kephra::config{search}{history}{current_replace_item};
+	my $new = shift;
+	if (defined $new and $new ne $old){
+		$Kephra::config{search}{history}{current_replace_item} = $new;
+		Kephra::API::EventTable::trigger('replace.item.changed');
+	}
+}
+
+sub set_selection_as_replace_item{
+	set_replace_item( Kephra::App::EditPanel::_ref()->GetSelectedText )
+}
+
 sub replace_selection  {
 	Kephra::App::EditPanel::_ref()->ReplaceSelection( get_replace_item() )
 }
@@ -204,30 +201,32 @@ sub replace_selection  {
 sub _find_next  {
 	my $ep = Kephra::App::EditPanel::_ref();
 	$ep->SearchAnchor;
-	$found_pos = $ep->SearchNext( $flags, get_find_item() );
-	Kephra::EventTable::trigger('find');
-	return $found_pos;
+	return $Kephra::temp{search}{item}{found} = $ep->SearchNext(
+		$Kephra::temp{search}{flags},
+		get_find_item()
+	);
 }
 
 sub _find_prev {
 	my $ep = Kephra::App::EditPanel::_ref();
 	$ep->SearchAnchor;
-	$found_pos = $ep->SearchPrev( $flags, get_find_item() );
-	Kephra::EventTable::trigger('find');
-	return $found_pos;
+	return $Kephra::temp{search}{item}{found} = $ep->SearchPrev(
+		$Kephra::temp{search}{flags},
+		get_find_item()
+	);
 }
 
 sub _find_first {
-	Kephra::Edit::Goto::_pos(0);
+	Kephra::Edit::Goto::pos(0);
 	_find_next();
 }
 
 sub _find_last  {
-	Kephra::Edit::Goto::_pos(-1);
+	Kephra::Edit::Goto::pos(-1);
 	_find_prev();
 }
 
-
+# find related menu calls
 sub first_increment {
 	my $ep = Kephra::App::EditPanel::_ref();
 	if ( _exist_find_item() ) {
@@ -238,38 +237,42 @@ sub first_increment {
 			return 1;
 		}
 	}
-	Kephra::Edit::Goto::_pos( $old_pos ) if defined $old_pos;
+	$ep->GotoPos( $Kephra::temp{search}{old_pos} )
+		if defined $Kephra::temp{search}{old_pos};
 	return 0;
 }
 
 #sub next_increment {}
-# find related menu calls
-sub find_all {
-#Kephra::Dialog::msg_box(&Wx::wxUNICODE(), '');
+
+sub find_all{
+#Kephra::Dialog::msg_box(undef, Wx::wxUNICODE(), '');
 	my $ep = Kephra::App::EditPanel::_ref();
 	if ( _exist_find_item() ) {
 		my $search_result = _find_first();
 		my ($sel_start, $sel_end);
-		#Kephra::Dialog::msg_box( , '');
-		#$ep->IndicatorSetStyle(0, &Wx::wxSTC_INDIC_TT );
-		#$ep->IndicatorSetForeground(0, &Wx::Colour->new(0xff, 0x00, 0x00));
-		$ep->IndicatorSetStyle(1, &Wx::wxSTC_INDIC_TT );
-		$ep->IndicatorSetForeground(1, &Wx::Colour->new(0xff, 0x00, 0x00));
-		# ^= &Wx::wxSTC_INDIC_STRIKE;
+		#Kephra::Dialog::msg_box(undef, , '');
+		#$ep->IndicatorSetStyle(0, wxSTC_INDIC_TT );
+		#$ep->IndicatorSetForeground(0, Wx::Colour->new(0xff, 0x00, 0x00));
+		#$ep->IndicatorSetStyle(1, wxSTC_INDIC_TT );
+		#$ep->IndicatorSetForeground(1, Wx::Colour->new(0xff, 0x00, 0x00));
+		$ep->IndicatorSetStyle(1, wxSTC_INDIC_TT );
+		$ep->IndicatorSetForeground(1, Wx::Colour->new(0xff, 0x00, 0x00));
+		# ^= wxSTC_INDIC_STRIKE;
 		$ep->SetSelection(0,0);
 		return 0 if $search_result == -1;
 		while ($search_result > -1){
 			($sel_start, $sel_end) = $ep->GetSelection;
-			Kephra::Edit::Goto::_pos( $sel_end );
+			Kephra::Edit::Goto::pos( $sel_end );
 			$ep->StartStyling($sel_start, 224);#224
 			$ep->SetStyleBytes($sel_end - $sel_start, 128);
 			$search_result = _find_next();
 		}
-		Kephra::Edit::Goto::_pos( $sel_end );
+		Kephra::Edit::Goto::pos( $sel_end );
 		$ep->Colourise( 0, $sel_end);
 		return 1;
 	} else {
-		Kephra::Edit::Goto::_pos( $old_pos ) if defined $old_pos;
+		$ep->GotoPos( $Kephra::temp{search}{old_pos} )
+			if defined $Kephra::temp{search}{old_pos};
 		return 1;
 	}
 }
@@ -280,25 +283,28 @@ sub find_prev {
 	my $return = -1;
 	if ( _exist_find_item() ) {
 		Kephra::Edit::_save_positions;
-		Kephra::Edit::Goto::_pos( $ep->GetSelectionStart - 1 );
+		Kephra::Edit::Goto::pos( $ep->GetSelectionStart - 1 );
 		$return = _find_prev();
 		if ( $return == -1 ) {
 			if ( get_range() eq 'document' ) {
 				$return = _find_last() if $attr->{auto_wrap};
 			} elsif ( get_range() eq 'open_docs' ) {
 				$Kephra::temp{dialog}{control} = 1;
-				my $begin_doc = Kephra::Document::Data::current_nr();
+				my $begin_doc = Kephra::Document::current_nr();
 				while ( $return == -1 ) {
 					Kephra::Edit::_restore_positions;
-					last if ( ( Kephra::Document::Data::current_nr() == 0 )
-						 and !$attr->{auto_wrap} );
+					last
+						if ( ( Kephra::Document::current_nr() == 0 )
+						and !$attr->{auto_wrap} );
 					Kephra::Document::Change::tab_left();
 					Kephra::Edit::_save_positions();
 					$return = _find_last();
 					last
-						if ( Kephra::Document::Data::current_nr() == $begin_doc );
+						if ( Kephra::Document::current_nr() == $begin_doc );
 				}
 				$Kephra::temp{dialog}{control} = 0;
+				Kephra::Dialog::Search::_ref()->Raise
+					if $Kephra::temp{dialog}{search}{active};
 			}
 		}
 		if ( $return == -1 ) { Kephra::Edit::_restore_positions() }
@@ -315,25 +321,27 @@ sub find_next {
 
 	if ( _exist_find_item() ) {
 		Kephra::Edit::_save_positions();
-		Kephra::Edit::Goto::_pos( $ep->GetSelectionEnd );
+		Kephra::Edit::Goto::pos( $ep->GetSelectionEnd );
 		$return = _find_next();
 		if ( $return == -1 ) {
 			if ( get_range() eq 'document' ) {
 				$return = _find_first() if $attr->{auto_wrap};
 			} elsif ( get_range() eq 'open_docs' ) {
 				$Kephra::temp{dialog}{control} = 1;
-				my $begin_doc = Kephra::Document::Data::current_nr();
+				my $begin_doc = Kephra::Document::current_nr();
 				while ( $return == -1 ) {
 					Kephra::Edit::_restore_positions();
-					last if Kephra::Document::Data::current_nr()
-							== Kephra::Document::Data::last_nr()
+					last if Kephra::Document::current_nr()
+							== Kephra::Document::last_nr()
 						 and not $attr->{auto_wrap};
 					Kephra::Document::Change::tab_right();
 					Kephra::Edit::_save_positions();
 					$return = _find_first();
-					last if ( Kephra::Document::Data::current_nr() == $begin_doc );
+					last if ( Kephra::Document::current_nr() == $begin_doc );
 				}
 				$Kephra::temp{dialog}{control} = 0;
+				Kephra::Dialog::Search::_ref()->Raise
+					if $Kephra::temp{dialog}{search}{active};
 			}
 		}
 		if ( $return == -1 ) { Kephra::Edit::_restore_positions() }
@@ -350,24 +358,26 @@ sub fast_back {
 	if (_exist_find_item()) {
 		for ( 1 .. $attr->{fast_steps} ) {
 			Kephra::Edit::_save_positions();
-			Kephra::Edit::Goto::_pos( $ep->GetSelectionStart - 1 );
+			Kephra::Edit::Goto::pos( $ep->GetSelectionStart - 1 );
 			$return = _find_prev();
 			if ( $return == -1 ) {
 				if ( get_range() eq 'document' ) {
 					$return = _find_last() if $attr->{auto_wrap};
 				} elsif ( get_range() eq 'open_docs' ) {
 					$Kephra::temp{dialog}{control} = 1;
-					my $begin_doc = Kephra::Document::Data::current_nr();
+					my $begin_doc = Kephra::Document::current_nr();
 					while ( $return == -1 ) {
 						Kephra::Edit::_restore_positions();
-						last if Kephra::Document::Data::current_nr() == 0
+						last if Kephra::Document::current_nr() == 0
 							and not $attr->{auto_wrap};
 						Kephra::Document::Change::tab_left();
 						Kephra::Edit::_save_positions();
 						$return = _find_last();
-						last if Kephra::Document::Data::current_nr() == $begin_doc;
+						last if Kephra::Document::current_nr() == $begin_doc;
 					}
 					$Kephra::temp{dialog}{control} = 0;
+					Kephra::Dialog::Search::_ref()->Raise
+						if $Kephra::temp{dialog}{search}{active};
 				}
 			}
 			refresh_find_history($return) if ( $_ == 1 );
@@ -384,25 +394,27 @@ sub fast_fore {
 	if (_exist_find_item()) {
 		for ( 1 .. $attr->{fast_steps} ) {
 			Kephra::Edit::_save_positions();
-			Kephra::Edit::Goto::_pos( $ep->GetSelectionEnd );
+			Kephra::Edit::Goto::pos( $ep->GetSelectionEnd );
 			$return = _find_next();
 			if ( $return == -1 ) {
 				if ( get_range() eq 'document' ) {
 					$return = _find_first() if $attr->{auto_wrap};
 				} elsif ( get_range() eq 'open_docs' ) {
 					$Kephra::temp{dialog}{control} = 1;
-					my $begin_doc = Kephra::Document::Data::current_nr();
+					my $begin_doc = Kephra::Document::current_nr();
 					while ( $return == -1 ) {
 						Kephra::Edit::_restore_positions();
-						last if Kephra::Document::Data::current_nr()
-								== Kephra::Document::Data::last_nr()
+						last if Kephra::Document::current_nr()
+								== Kephra::Document::last_nr()
 							and not $attr->{auto_wrap};
 						Kephra::Document::Change::tab_right();
 						Kephra::Edit::_save_positions();
 						$return = _find_first();
-						last if Kephra::Document::Data::current_nr() == $begin_doc;
+						last if Kephra::Document::current_nr() == $begin_doc;
 					}
 					$Kephra::temp{dialog}{control} = 0;
+					Kephra::Dialog::Search::_ref()->Raise
+						if $Kephra::temp{dialog}{search}{active};
 				}
 			}
 			refresh_find_history($return) if $_ == 1;
@@ -428,7 +440,7 @@ sub find_first {
 			set_range('selection') 
 		}
 		if ( get_range() eq 'selection' ) {
-			Kephra::Edit::Goto::_pos($sel_begin);
+			Kephra::Edit::Goto::pos($sel_begin);
 			$return = _find_next();
 			if ($return > -1 and $ep->GetCurrentPos + $len <= $sel_end) {
 				Kephra::Edit::_center_caret();
@@ -442,17 +454,19 @@ sub find_first {
 			and ($sel_begin == $ep->GetSelectionStart or $return == -1 ) ){
 				$Kephra::temp{dialog}{control} = 1;
 				$return = -1;
-				my $begin_doc = Kephra::Document::Data::current_nr();
+				my $begin_doc = Kephra::Document::current_nr();
 				while ( $return == -1 ) {
 					Kephra::Edit::_restore_positions();
-					last if Kephra::Document::Data::current_nr() == 0
+					last if Kephra::Document::current_nr() == 0
 						and not $attr->{auto_wrap};
 					Kephra::Document::Change::tab_left();
 					Kephra::Edit::_save_positions();
 					$return = _find_first();
-					last if ( Kephra::Document::Data::current_nr() == $begin_doc );
+					last if ( Kephra::Document::current_nr() == $begin_doc );
 				}
 				$Kephra::temp{dialog}{control} = 0;
+				Kephra::Dialog::Search::_ref()->Raise
+					if $Kephra::temp{dialog}{search}{active};
 			}
 			if ( $return > -1 ) {
 				_caret_2_sel_end();
@@ -482,7 +496,7 @@ sub find_last {
 			set_range('selection');
 		}
 		if ( get_range() eq 'selection' ) {
-			Kephra::Edit::Goto::_pos($sel_end);
+			Kephra::Edit::Goto::pos($sel_end);
 			$return = _find_prev();
 			if ($return > -1 and $ep->GetCurrentPos >= $sel_begin) {
 				Kephra::Edit::_center_caret();
@@ -496,18 +510,20 @@ sub find_last {
 				and ($sel_begin == $ep->GetSelectionStart or $return == -1) ){
 				$Kephra::temp{dialog}{control} = 1;
 				$return = -1;
-				my $begin_doc = Kephra::Document::Data::current_nr();
+				my $begin_doc = Kephra::Document::current_nr();
 				while ( $return == -1 ) {
 					Kephra::Edit::_restore_positions();
-					last if Kephra::Document::Data::current_nr()
-							== Kephra::Document::Data::last_nr()
+					last if Kephra::Document::current_nr()
+							== Kephra::Document::last_nr()
 						and not $attr->{auto_wrap};
 					Kephra::Document::Change::tab_right();
 					Kephra::Edit::_save_positions();
 					$return = _find_last();
-					last if ( Kephra::Document::Data::current_nr() == $begin_doc );
+					last if ( Kephra::Document::current_nr() == $begin_doc );
 				}
 				$Kephra::temp{dialog}{control} = 0;
+				Kephra::Dialog::Search::_ref()->Raise
+					if $Kephra::temp{dialog}{search}{active};
 			}
 			if ( $return > -1 ) {
 				_caret_2_sel_end();
@@ -555,7 +571,7 @@ sub replace_all {
 		}
 		if ( get_range() eq 'selection' ) {
 			$ep->BeginUndoAction;
-			Kephra::Edit::Goto::_pos($sel_begin);
+			$ep->GotoPos($sel_begin);
 			while ( _find_next() > -1 ) {
 				last if ( $ep->GetCurrentPos + $len >= $sel_end );
 				$ep->ReplaceSelection($replace_string);
@@ -563,18 +579,18 @@ sub replace_all {
 			$ep->EndUndoAction;
 		} elsif ( get_range() eq 'document' ) {
 			$ep->BeginUndoAction;
-			Kephra::Edit::Goto::_pos(0);
+			$ep->GotoPos(0);
 			while ( _find_next() > -1 ) {
 				$ep->ReplaceSelection($replace_string);
 			}
 			$ep->EndUndoAction;
 		} elsif ( get_range() eq 'open_docs' ) {
-			my $begin_doc = Kephra::Document::Data::current_nr();
+			my $begin_doc = Kephra::Document::current_nr();
 			do {
 				{
 					Kephra::Edit::_save_positions();
 					$ep->BeginUndoAction;
-					Kephra::Edit::Goto::_pos(0);
+					$ep->GotoPos(0);
 					while ( _find_next() > -1 ) {
 						$ep->ReplaceSelection($replace_string);
 					}
@@ -597,7 +613,7 @@ sub replace_confirm {
 		my $len  = _exist_find_item();
 		my $sel_begin = $ep->GetSelectionStart;
 		my $sel_end   = $ep->GetSelectionEnd;
-		my $answer    = &Wx::wxYES;
+		my $answer    = wxYES;
 		my $menu_call = shift;
 
 		set_range('selection')
@@ -610,10 +626,10 @@ sub replace_confirm {
 		} elsif (get_range() eq 'document') {
 			sniff_selection( $ep, 0, $ep->GetTextLength, $len, $line );
 		} elsif (get_range() eq 'open_docs') {
-			my $begin_doc = Kephra::Document::Data::current_nr();
+			my $begin_doc = Kephra::Document::current_nr();
 			do {
 				{
-					next if $answer == &Wx::wxCANCEL;
+					next if $answer == wxCANCEL;
 					Kephra::Edit::_save_positions();
 					$answer = sniff_selection
 						( $ep, 0, $ep->GetTextLength, $len, $line );
@@ -625,21 +641,21 @@ sub replace_confirm {
 
 	sub sniff_selection {
 		my ( $ep, $sel_begin, $sel_end, $len, $line ) = @_;
-		my $l10n = Kephra::Config::Localisation::strings()->{dialog}{search}{confirm};
+		my $l10n = $Kephra::localisation{dialog}{search}{confirm};
 		my $answer;
-		Kephra::Edit::Goto::_pos($sel_begin);
+		Kephra::Edit::Goto::pos($sel_begin);
 		$ep->BeginUndoAction();
 		while ( _find_next() > -1 ) {
 			last if $ep->GetCurrentPos + $len >= $sel_end;
 			Kephra::Edit::_center_caret();
 			$answer = Kephra::Dialog::get_confirm_3
-				($l10n->{text}, $l10n->{title}, 100, 100);
-			last if $answer == &Wx::wxCANCEL;
-			if ($answer == &Wx::wxYES) {replace_selection()}
-			else                    {$ep->SetCurrentPos( $ep->GetCurrentPos + 1 )}
+				(undef, $l10n->{text}, $l10n->{title}, 100, 100);
+			last if $answer == wxCANCEL;
+			if ($answer == wxYES) {replace_selection()}
+			else                  {$ep->SetCurrentPos( $ep->GetCurrentPos + 1 )}
 		}
 		$ep->EndUndoAction;
-		Kephra::Edit::Goto::_pos( $ep->PositionFromLine($line) );
+		Kephra::Edit::Goto::pos( $ep->PositionFromLine($line) );
 		Kephra::Edit::_center_caret();
 		$answer;
 	}
@@ -647,12 +663,31 @@ sub replace_confirm {
 	Kephra::Edit::_keep_focus();
 }
 
+
+#
+package SearchInputTarget;
+our $VERSION = '0.04';
+
+use strict;
+use base qw(Wx::TextDropTarget);
+
+sub new {
+	my $class  = shift;
+	my $target  = shift;
+	my $kind  = shift;
+	my $self = $class->SUPER::new(@_);
+	$self->{target} = $target if substr(ref $target, 0, 12) eq 'Wx::ComboBox';
+	$self->{kind} = $kind;
+	return $self;
+}
+
+sub OnDropText {
+	my ( $self, $x, $y, $text ) = @_;
+	$self->{target}->SetValue( $text ) if $self->{target};
+	$self->{kind} eq 'replace'
+		? Kephra::Edit::Search::set_replace_item($text)
+		: Kephra::Edit::Search::set_find_item($text);
+	0; #dont skip event
+}
+
 1;
-
-=head1 NAME
-
-Kephra::Edit::Search - find and replace functions
-
-=head1 DESCRIPTION
-
-=cut
\ No newline at end of file
